@@ -6,6 +6,8 @@ test_that("Run glmshow.display", {
   expect_is(glmshow.display(glm(mpg ~ cyl + disp, data = mtcars)), "display")
   expect_is(glmshow.display(glm(am ~ cyl, data = mtcars, family = "binomial")), "display")
   expect_is(glmshow.display(glm(am ~ cyl + disp, data = mtcars, family = "binomial")), "display")
+  expect_is(glmshow.display(glm(am ~ cyl + disp, data = mtcars, family = "binomial"),pcut.univariate = 0.0055), "display")
+  expect_is(glmshow.display(glm(mpg ~ factor(am) +wt+qsec, data = mtcars, family = "gaussian"), pcut.univariate = 0.01), "display")
 })
 
 test_that("Run cox2.display", {
@@ -29,8 +31,10 @@ test_that("Run svyglm.display", {
   ds <- svyglm(api00 ~ ell + meals, design = dstrat)
   expect_is(svyregress.display(ds, decimal = 3), "display")
   expect_is(svyregress.display(svyglm(api00 ~ ell, design = dstrat), decimal = 3), "display")
+  expect_is(svyregress.display(ds, decimal = 3, pcut.univariate = 0.05), "display")
   ds2 <- svyglm(tt ~ ell + meals + cname + mobility, design = dstrat, family = quasibinomial())
   expect_is(svyregress.display(ds2, decimal = 3), "display")
+  expect_is(svyregress.display(ds2, decimal = 3, pcut.univariate = 0.05), "display")
 })
 
 test_that("Run svycox.display", {
@@ -47,6 +51,8 @@ test_that("Run svycox.display", {
   dpbc <- survey::svydesign(id = ~1, prob = ~randprob, strata = ~edema, data = subset(pbc, randomized))
   model <- survey::svycoxph(Surv(time, status > 0) ~ sex + protime + albumin + stage, design = dpbc)
   expect_is(svycox.display(model), "list")
+  expect_is(svycox.display(model, pcut.univariate = 0.02), "list")
+  expect_is(svycox.display(model, pcut.univariate = 0.001), "list")
 })
 
 
@@ -59,6 +65,8 @@ test_that("Run geeglm.display", {
   dietox$Weight_cat <- as.integer(dietox$Weight > 50)
   expect_is(geeglm.display(geeglm(Weight_cat ~ Time, id = Pig, data = dietox, family = binomial, corstr = "ex")), "list")
   expect_is(geeglm.display(geeglm(Weight_cat ~ Time + Cu, id = Pig, data = dietox, family = binomial, corstr = "ex")), "list")
+  expect_is(geeglm.display(geeglm(Weight ~ Time + Cu, id = Pig, data = dietox, family = gaussian, corstr = "ex"),pcut.univariate =0.05), "list")
+  expect_is(geeglm.display(geeglm(Weight_cat ~ Time + Cu, id = Pig, data = dietox, family = binomial, corstr = "ex"),pcut.univariate = 0.05), "list")
 })
 
 
@@ -67,7 +75,10 @@ library(lme4)
 test_that("Run lmer.display", {
   expect_is(lmer.display(lmer(Reaction ~ Days + (1 | Subject), sleepstudy)), "list")
   expect_is(lmer.display(lmer(Weight ~ Time + Feed + (1 | Pig) + (1 | Evit), data = dietox)), "list")
+  expect_is(lmer.display(lmer(Weight ~ Time + Feed + (1 | Pig) + (1 | Evit), data = dietox),pcut.univariate = 0.05), "list")
   dietox$Weight_cat <- as.integer(dietox$Weight > 50)
   expect_is(lmer.display(glmer(Weight_cat ~ Time + Cu + (1 | Pig) + (1 | Evit), data = dietox, family = binomial)), "list")
   expect_is(lmer.display(glmer(Weight_cat ~ Time + (1 | Pig) + (1 | Evit), data = dietox, family = binomial)), "list")
+  expect_is(lmer.display(glmer(Weight_cat ~ Time + Cu + (1 | Pig) + (1 | Evit), data = dietox, family = binomial),pcut.univariate = 0.05), "list")
+  expect_is(lmer.display(glmer(Weight_cat ~ Time + Cu + (1 | Pig) + (1 | Evit), data = dietox, family = binomial),pcut.univariate = 0.6), "list")
 })
